@@ -1,5 +1,4 @@
 """Test the application module"""
-import asyncio
 import unittest
 from common.app import ApplicationBase, application_entrypoint, terminate
 from common.config import Config
@@ -13,8 +12,6 @@ class TestApplication(ApplicationBase):
     async def start(self):
         """Starts the application, and sets up the internal modules and services"""
         self.logger.info("app starts")
-        # task = asyncio.create_task(terminate_after())
-        # await task
 
     async def stop(self):
         """Shuts down the application"""
